@@ -71,9 +71,10 @@ class BaseModel(object):
         simulation description
     
     """
-    def __init__(self, sim):
+    def __init__(self, sim, warn=False):
         self.sim = sim
         self.set_step(sim.struct.step)
+        self.warn = warn
 
 
     def set_step(self, step):
@@ -134,7 +135,8 @@ class BaseModel(object):
             else:
                 material = self.sim.struct.material
         
-        struct = structures.struct(self.sim.struct.step, geometry, material, verbose=False)
+        struct = structures.struct(self.sim.struct.step, geometry, material, 
+                                   verbose=False, warn=self.warn)
         
         self.sim.struct = struct
         self.sim.struct.setDtype(self.sim.dtypef, self.sim.dtypec)
