@@ -646,7 +646,7 @@ def _get_K_as_matrix(K, method):
     ## --- get explicit matrix
     if method.lower() == 'lu':
         import scipy.linalg as la
-        K = la.lu_solve(K, np.identity(K.shape[0], dtype=K[0].dtype))
+        K = la.lu_solve(K, np.identity(K[0].shape[0], dtype=K[0].dtype))
     if method.lower() in ['cuda', "cupy"] and type(K) != np.ndarray:
             K = K.get()
     return K
@@ -677,7 +677,7 @@ def _do_double_integral(K, Q, S, chi, Sp):
                 for l in range(3): 
                     for m in range(3): 
                         for k in range(3): 
-                            Sp[i_probe,l,m] += Q[i_probe,i,k,m] * S_tmp2[k,m]
+                            Sp[i_probe,m,l] += Q[i_probe,i,l,k] * S_tmp2[k,m]
 
 
 def decay_rate(sim, field_index=None, wavelength=None, 
