@@ -1,6 +1,6 @@
 # encoding: utf-8
 #
-#Copyright (C) 2017-2021, P. R. Wiecha
+#Copyright (C) 2017-2022, P. R. Wiecha
 #
 #This program is free software: you can redistribute it and/or modify
 #it under the terms of the GNU General Public License as published by
@@ -97,6 +97,9 @@ class struct(object):
     check_geometry_consistency : bool, default: True
         whether to test geometry for consistency. If yes, inconsistent 
         meshpoints will be removed and a warning will be produced
+            
+    warn: bool, default: True
+        show warnings if detection fails
         
     verbose : int, default: 1
         0: print nothing, 1: print some runtime info
@@ -106,7 +109,7 @@ class struct(object):
     def __init__(self, step, geometry, material, n1=None, n2=None, 
                  normalization='auto', n3=None, spacing=5000.0,
                  auto_shift_structure=False, check_geometry_consistency=True, 
-                 verbose=True):
+                 warn=True, verbose=True):
         """Initialization"""
         ## set precision to single by default
         self.setDtype(np.float32, np.complex64)
@@ -116,7 +119,7 @@ class struct(object):
         self.step = step
         if type(normalization)==str:
             if normalization.lower() == 'auto':
-                normalization = tools.get_mesh_from_geometry(geometry)
+                normalization = tools.get_mesh_from_geometry(geometry, warn=warn)
                 if verbose:
                     print("structure initialization - automatic mesh detection: {}".format(normalization))
                 
@@ -137,8 +140,9 @@ class struct(object):
         if n1 is not None and n2 is not None:
             self.n1_material, self.n2_material, self.n3_material = _n_env123_to_materials(n1, n2, n3)
             self.spacing = spacing
-            warnings.warn("Deprecation: environment should be defined thorugh the `dyads` interface. " +
-                          "Using the `struct` class is not recommended and will raise an error in future versions.")
+            if warn:
+                warnings.warn("Deprecation: environment should be defined thorugh the `dyads` interface. " +
+                              "Using the `struct` class is not recommended and will raise an error in future versions.")
             
         
         ## --- geometry
@@ -150,8 +154,9 @@ class struct(object):
             self.geometry, _wrong_dipoles, index_correct = tools.test_geometry(
                                 geometry, step, return_index=True, plotting=False)
             if len(_wrong_dipoles) != 0:
-                warnings.warn("using only consistent part of structure. " +
-                              "Please verify the geometry.")
+                if warn:
+                    warnings.warn("using only consistent part of structure. " +
+                                  "Please verify the geometry.")
                 
             if verbose:
                 print("structure initialization - consistency check: {}/{} dipoles valid".format(len(self.geometry), len(geometry)))
@@ -181,8 +186,13 @@ class struct(object):
                 self.material = [material for i in range(len(self.geometry))]
         
         else:
-            warnings.warn("Emtpy structure geometry.")
+            if warn:
+                warnings.warn("Emtpy structure geometry.")
             self.material = material
+            
+        ## --- center of gravity
+        self.r0 = np.average(self.geometry, axis=0)
+         
     
     
     def __repr__(self, verbose=False):
